#### 绑定接口

##### 简要描述

  - 通过该接口可以将号码A通过orderID与号码B进行绑定，号码A+orderID跟号码B一对一匹配。号码绑定的同时返回sip话机的鉴权信息sipId和sipPassword。

    A呼叫B场景中，可以通过号码A+orderID找到号码B。B呼叫A场景中，可以通过号码B直接找到号码A。

    比如派送场景中，号码A为派送员号码，号码B为客户号码。
	
	A号码绑定多个B号码时，通过orderID进行区分。通过手机拨打X号码时，存在多个绑定关系时，接通后输入orderId转接到对应B号码

    对同一个订单进行多次绑定时进行覆盖操作。

    

##### 请求URL

  - ` http://{ip}:{port}/api/sdk/dc/bind  `

##### 请求方式

  - post

##### Header

| header       | 必选 | 类型   | 说明                            |
| :----------- | :--- | ------ | ------------------------------- |
| Content-Type | 是   | string | application/json; charset=utf-8 |

##### 请求参数

| 参数名     | 必选 | 类型    | 说明                                         |
| :--------- | :--- | ------- | -------------------------------------------- |
| token | string | 必须  |通过授权接口获取的token|
| telA       | 是   | string  | 号码A                                        |
| telB       | 是   | string  | 号码B                            |
| orderId    | 是   | string  | 流水号，一般设置为4位以内的数字。在telA绑定多个telB时，telA通过手机拨打，在拨号盘输入orderId转到指定的telB，如果telA是sdk方式拨打，保证orderid不重复即可。                          |
| callnum       | 否   | string  | 外显号码，为空时使用企业默认主叫                            |
| expiration | 否   | Integer | 绑定关系有效时间，单位秒，如果不传为永久有效 |
| userData | 否 | string | 用户自定义数据，比如订单号|
| source | 否 | string | 订单来源|
| areaCode | 否 | Integer | 订单产生所在地区号|
| terminalInfo | 否 | string | 终端详情。获取方法：Android SDK：VXManager.INSTANCE.getClientInfo() ; IOS SDK：[[VXCallManager sharedInstance]deviceInfo]|


##### 请求示例

```
{
  "telA":"1380000****",
  "telB":"1380000****",
  "orderId":"1235",
  "expiration":72000,
  "userData":"10000100101001",
  "terminalInfo":"{\"appVersion\":\"1.3\",\"imei\":\"A1B387D22E697A8605776F7B7794F9A69FB365F6\",\"network\":\"120.30.40.50 192.168.1.0 255.0.0.0\",\"networkType\":\"WIFI\",\"phoneModel\":\"Meizu16th\",\"sdkVersion\":\"1.0.5\",\"sysType\":\"Android\",\"sysVersion\":\"8.1.0\"}"
}
```



##### 返回示例

```
{
    "msg":"绑定成功",
    "code":"0000",
    "data":{
        "sipId":"2200000000203",
        "sipPassword":"341d21877cc4",
        "sipIP":"120.30.40.50",
        "sipPort":"5060",
        "wsAddress":"wss://120.30.40.50:8443",
		"domain":"120.30.40.50:5060",
        "serviceParams":{
            "openStun":false,
            "openIce":false,
            "tcp":false,
            "stunService":"120.30.40.50",
            "codeC":"OPUS",
            "sendLog":false,
            "uploadLog":false,
            "uploadLogUrl":"http://120.30.40.50:8084"
        },
        "autoSwitch":0
    }
}
```

##### 返回参数说明

| 参数名 | 类型   | 说明     |
| :----- | :----- | -------- |
| msg    | string | 返回说明 |
| code   | String | 返回code |
| data   | Object | 返回数据 |

##### data说明

| 参数名      | 类型   | 说明          |
| ----------- | ------ | ------------- |
| sipId       | String | sip鉴权id     |
| sipPassword | String | sip鉴权密码   |
| sipIP       | String | sip服务器ip  |
| sipPort     | String | sip服务器端口 |
| wsAddress     | String | ws地址 |
| domain     | String | 域 |
| serviceParams     | Object | sdk控制信息，透传给sdk |
| ├ openStun     | Boolean | 是否开启stun,默认false |
| ├ openIce     | Boolean | 是否开启ice,默认false |
| ├ tcp     | Boolean | 是否Tcp |
| ├ stunService     | String | stun服务器地址 |
| ├ codeC     | String | 音频编码 |
| ├ sendLog     | Boolean | 通过IM发送实时日志的标识,默认false |
| ├ uploadLog     | Boolean | 是否立即通过http上传日志,默认false |
| ├ uploadLogUrl     | String | 通过http上传日志的服务器地址 |



##### code说明

| code | msg                          | 说明                                    |
| :--- | :--------------------------- | --------------------------------------- |
| 0000 | 绑定成功                     |                                         |
| 0001 | 覆盖绑定成功                 | 可对相同的号码B进行重复绑定，绑定时覆盖 |
| 2001 | 绑定失败，telA为空           |                                         |
| 2002 | 绑定失败，telA为空           |                                         |
| 2003 | 绑定失败，orderID为空        |                                         |
| 2004 | 绑定失败，expiration格式错误 |                                         |