##### 简要描述
  - 使用HTTP的POST请求，发送短信

##### 请求URL
  - http://{ip:port}/openapi/message/sms/send

##### 请求方式
  - POST

##### Header

| header       | 必选 | 类型   | 说明                            |
| :----------- | :--- | ------ | ------------------------------- |
| Content-Type | 是   | string | application/json; charset=utf-8 |

##### 请求参数

| 参数          | 必选 | 类型   | 描述                                   |
| ------------- | ---- | ------ | -------------------------------------- |
| templateId        | 是   | String | 模板ID             |
| msgs    | 是   | object [] |短信列表，建议最大数量小于500 |
| phone    | 是   | string |短信发送号码 |
| userData | 否   | string | 用户自定义数据，回调返回，最大长度100               |
| params | 否   | json |短信参数列表，与模板中定义参数一致 |
| token | 是 | string |通过授权接口获取的token|


##### 请求示例

```
{
	"templateId": "e1ad91dd75a04fe987a7cc669872d062",
	"msgs": [{
		"phone": "133xxxxxxxx",
		"userData": "1636535406828",
		"params": {
			"userName": "张三",
			"verifyCode": "901524"
		}
	}, {
		"phone": "188xxxxxxxx",
		"userData": "1636535406829",
		"params": {
			"userName": "李四",
			"verifyCode": "900975"
		}
	}],
	"token": "1287c6e2ebfb4a29720a8aba749aa27a"
}

```

##### 返回示例
1.成功示例
说明：批量发送时有一条短信发送成功外部code即为"0"，successes列表中返回的数据为发送成功的短信记录，为节省网络带宽params字段不再返回
```
{
	"code": "0",
	"data": {
		"successes": [{
			"msgId": "5fcffcf6d25d4353968056f5a4113047",
			"phone": "133xxxxxxxx"
			"code": "0",
			"msg": "success"
		}, {
			"msgId": "98af09d3e5b5effebfdb07aee5c57841",
			"phone": "188xxxxxxxx"
			"code": "0",
			"msg": "success"
		}],
		"taskId": "e7052a45ebf14401af0a1759e9a617c6",
		"totalCount": 2,
		"errorCount": 0
	},
	"msg": "success"
}
```
```
{
	"code": "0",
	"data": {
		"successes": [{
			"msgId": "5fcffcf6d25d4353968056f5a4113047",
			"phone": "133xxxxxxxx",
			"code": "0",
			"msg": "success"
		}],
		"errors": [{
			"phone": "188xxxxxxxx",
			"userData": "1636535406829",
			"params": {
				"userName": "李四",
				"verifyCode": "900975"
			},
			"code": "-1",
			"msg": "验证码错误"
		}],
		"taskId": "e7052a45ebf14401af0a1759e9a617c6",
		"totalCount": 2,
		"errorCount": 1
	},
	"msg": "success"
}
```
2.异常示例
说明：当外部code不等于"0"时errors列表返回发送失败的短信信息
```
{
	"code": "-1",
	"data": {
		"errors": [{
			"phone": "133xxxxxxxx",
			"userData": "1636535406828",
			"params": {
				"userName": "张三",
				"verifyCode": "901524"
			},
			"code": "-1",
			"msg": "验证码错误"
		}, {
			"phone": "188xxxxxxxx",
			"userData": "1636535406829",
			"params": {
				"userName": "李四",
				"verifyCode": "900975"
			},
			"code": "-1",
			"msg": "验证码错误"
		}],
		"taskId": "e7052a45ebf14401af0a1759e9a617c6",
		"totalCount": 2,
		"failCount": 2
	},
	"msg": "短信验证未通过"
}
```

##### 返回参数说明


|  名称 |  类型 |  是否必须 |  默认值 |  备注 |  其他信息 |
| --- | --- | --- | --- | --- | --- |
| code | string |  必须 |  |  |  |
| msg | string |  必须 |  |  |  |
| data | object |  非必须 |  |  |  |
| ├ taskId | string |  非必须 |  | 任务ID |  |
| ├ totalCount | integer |  非必须 |  | 总数量 |  |
| ├ errorCount | integer |  非必须 |  |  异常数量|  |
| └ successes | object [] |  非必须 |  | 成功列表 | item 类型:object | 
| └ errors | object [] |  非必须 |  | 失败列表 | item 类型:object | 
|&nbsp;&nbsp;&nbsp;&nbsp;├ msgId | string |  非必须 |  |短信唯一ID，短信投递成功时返回，最大长度32位，可用于查询结果和匹配回调 | |  |
|&nbsp;&nbsp;&nbsp;&nbsp;├ phone | string |  非必须 |  | 短信发送号码 |  |
|&nbsp;&nbsp;&nbsp;&nbsp;├ userData | string |  非必须 |  | 用户自定义数据 |  |
|&nbsp;&nbsp;&nbsp;&nbsp;├ params | json |  非必须 |  | 短信参数列表，string类型 |  |
|&nbsp;&nbsp;&nbsp;&nbsp;├ code | string |  非必须 |  | 单条短信状态码 |  |
|&nbsp;&nbsp;&nbsp;&nbsp;├ msg | string |  非必须 |  | 单条短信状态说明 |  |







##### code说明

| code | msg                          | 说明                                    |
| :--- | :--------------------------- | --------------------------------------- |
| 0 | 查询成功                         | 当且仅当code="0"时成功   |
| 403 | 鉴权失败                       |  |